#!/bin/bash
cd "${0%/*}"
# Get all serial devices in /dev/cu.* and store them in an array
files=()
while IFS=  read -r -d $'\0'; do
    files+=("$REPLY")
done < <(find /dev/cu.* -type c -maxdepth 1 -print0)

# Display a list with all serial devices and ask the user to choose a number
echo "Please choose a serial device:"
for i in "${!files[@]}"; do
    echo "$i: ${files[$i]}"
done

# Read the user input
read -p "Enter the number of the serial device: " -r
echo
# Check if the input is a number and if it is in the range of the array
if [[ $REPLY =~ ^[0-9]+$ ]] && [ $REPLY -lt ${#files[@]} ]; then
    # Get the selected serial device
    file=${files[$REPLY]}
    echo "Selected serial device: $file"
else
    echo "Invalid input"
    exit 1
fi

# Set the baud rate of the selected serial device to 1200
stty -f $file 1200 cs8 cread clocal

# Flash the bootloader, firmware and partition table to the ESP32
./esptool --chip esp32 --port $file --baud 921600 --before default_reset --after hard_reset write_flash -z --flash_mode dio --flash_freq 80m --flash_size detect 0x1000 bootloader.bin 0x20000 tdiflasher_firmware.bin 0x9000 partition-table.bin

exit